@@ -46,11 +46,11 @@ DateTime::Format::Genealogy - Create a DateTime object from a Genealogy Date
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ sub new {
 		# clone the given object
 		return bless { %{$class}, %args }, ref($class);
 	}
-	return bless {}, $class;
+	return bless { %args }, $class;
 }
 
 =head2 parse_datetime($string)
@@ -163,6 +163,8 @@ sub parse_datetime {
 				} elsif($2 eq 'Janv') {
 					# I've seen a tree that uses some French months
 					$date = "$1 Jan $3";
+				} elsif($2 eq 'Juli') {
+					$date = "$1 Jul $3";
 				} else {
 					Carp::carp("Unparseable date $date - often because the month name isn't 3 letters") unless($quiet);
 					return;
@@ -170,7 +172,11 @@ sub parse_datetime {
 			} elsif($date =~ /^(\d{1,2})\s+Mai\s+(\d{3,4})$/i) {
 				# I've seen a tree that uses some French months
 				$date = "$1 May $2";
+			} elsif($date =~ /^(\d{1,2})\-([A-Z]{3}+)\-(\d{3,4})$/i) {
+				# 29-Aug-1938
+				$date = "$1 $2 $3";
 			}
+
 			my $dfn = $self->{'dfn'};
 			if(!defined($dfn)) {
 				$self->{'dfn'} = $dfn = DateTime::Format::Natural->new();
